summaryrefslogtreecommitdiffstats
path: root/src/main.cpp
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2021-12-19 20:05:06 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2021-12-19 20:08:46 +0900
commitab12cfe230b06ba2a4505e681d7b8ce6ea35fb34 (patch)
treea6bb5fc600136016a2e3fd309ce6b3ad8a6c7cc9 /src/main.cpp
parent796d4dc1ab15ce7f898d3fc0014e4b64a0be155d (diff)
downloadpolkit-agent-tde-ab12cfe230b06ba2a4505e681d7b8ce6ea35fb34.tar.gz
polkit-agent-tde-ab12cfe230b06ba2a4505e681d7b8ce6ea35fb34.zip
Updated cmake files to allow building the package, although it is just a dummy package (not functional).
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp58
1 files changed, 34 insertions, 24 deletions
diff --git a/src/main.cpp b/src/main.cpp
index 414275d..11a62c5 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -1,4 +1,4 @@
/* This file is part of the KDE project
Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
This program is free software; you can redistribute it and/or
@@ -18,31 +18,41 @@
*/
-#include <TDECmdLineArgs>
-#include <TDEAboutData>
-#include <TDELocale>
-#include <TDECrash>
+#include <tdeaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdelocale.h>
-#include "policykitkde.h"
+#include <tqpushbutton.h>
+#include <tdeapplication.h>
+//#include "policykitkde.h"
int main(int argc, char *argv[])
{
- TDEAboutData aboutData("Polkit1AuthAgent", "polkit-kde-authentication-agent-1", ki18n("PolicyKit1-KDE"), "0.99.0",
- ki18n("PolicyKit1-KDE"), TDEAboutData::License_GPL,
- ki18n("(c) 2009 Red Hat, Inc."));
- aboutData.addAuthor(ki18n("Jaroslav Reznik"), ki18n("Maintainer"), "jreznik@redhat.com");
- aboutData.setProductName("policykit-kde/polkit-kde-authentication-agent-1");
-
- TDECmdLineArgs::init(argc, argv, &aboutData);
-
- if (!PolicyKitKDE::start()) {
- tqWarning("PolicyKitKDE is already running!\n");
- return 0;
- }
-
- TDECrash::setFlags(TDECrash::AutoRestart);
-
- PolicyKitKDE agent;
- agent.disableSessionManagement();
- agent.exec();
+ TDEAboutData aboutData("polkit-agent-tde", I18N_NOOP("Polkit-Agent-TDE"), "0.99.1",
+ I18N_NOOP("A Polkit authentication agent for TDE"), TDEAboutData::License_GPL,
+ I18N_NOOP("(c) 2009 Red Hat, Inc."));
+ aboutData.addAuthor(I18N_NOOP("Jaroslav Reznik"), I18N_NOOP("Maintainer"), "jreznik@redhat.com");
+ aboutData.setProductName("policykit-agent-tde");
+
+ TDECmdLineArgs::init(argc, argv, &aboutData);
+ TDEApplication app;
+ TQPushButton *pbQuit = new TQPushButton("Quit", 0);
+ app.setMainWidget(pbQuit);
+ app.connect(&app, TQT_SIGNAL(lastWindowClosed()), TQT_SLOT(quit()));
+ app.connect(pbQuit, TQT_SIGNAL(clicked()), &app, TQT_SLOT(quit()));
+ pbQuit->show();
+ return app.exec();
+
+ /*
+ if (!PolicyKitKDE::start()) {
+ tqWarning("PolicyKitKDE is already running!\n");
+ return 0;
+ }
+
+ TDECrash::setFlags(TDECrash::AutoRestart);
+
+ PolicyKitKDE agent;
+ agent.disableSessionManagement();
+ agent.exec();
+ */
}
@@ -1,4 +1,4 @@
-/* This file is part of the KDE project
+/* This file is part of the TDE project
Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
This program is free software; you can redistribute it and/or